# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section   free

Name:           proguard
Version:        4.5.1
Release:	1%{?dist}
Epoch:          0
Summary:        Java classfile shrinker, optimizer, obfuscator
Group:          Development/Libraries/Java
License:        GPLv2
URL:            http://proguard.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/proguard/proguard/4.5/proguard4.5.1.tar.gz
Source1:	proguard.script
Source2:	proguardgui.script
Source3:	retrace.script
Patch0:         proguard-build.patch
BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant
Requires:  jpackage-utils >= 0:1.7.5
Requires:  java >= 0:1.6.0
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
ProGuard is a free Java class file shrinker, optimizer, 
obfuscator, and preverifier. It detects and removes unused 
classes, fields, methods, and attributes. It optimizes 
bytecode and removes unused instructions. It renames the 
remaining classes, fields, and methods using short 
meaningless names. Finally, it preverifies the processed 
code for Java 6 or for Java Micro Edition.
Some uses of ProGuard are:
* Creating more compact code, for smaller code archives, 
  faster transfer across networks, faster loading, and 
  smaller memory footprints.
* Making programs and libraries harder to reverse-engineer.
* Listing dead code, so it can be removed from the source 
  code.
* Retargeting and preverifying existing class files for 
  Java 6, to take full advantage of Java 6's faster class 
  loading. 
ProGuard's main advantage compared to other Java obfuscators
is probably its compact template-based configuration. A few
intuitive command line options or a simple configuration
file are usually sufficient. For instance, the following
configuration option preserves all applets in a jar:
    -keep public class * extends java.applet.Applet
The user manual explains all available options and shows
more examples of this powerful configuration style.
ProGuard is fast. It only takes seconds to process programs
and libraries of several megabytes. The results section
presents actual figures for a number of applications.
ProGuard is a command-line tool with an optional graphical
user interface. It also comes with plugins for Ant and for
the JME Wireless Toolkit. 

%package        gui
Summary:        A GUI for %{name}
Group:          Development/Tools

%description    gui
%{summary}.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description    javadoc
%{summary}.

%package        manual
Summary:        Documents for %{name}
Group:          Development/Documentation

%description    manual
%{summary}.

%prep 
%setup -q -n %{name}%{version}
for j in $(find . -name "*.jar"); do
    mv $j $j.no
done
%patch0 -b .sav0

%build
ant -f build/build.xml -Dant.jar=$(build-classpath ant) basic anttask
mkdir apidocs
javadoc -d apidocs $(find src -name "*.java")

%install
rm -rf %{buildroot}

# bin
install -d -m 755 %{buildroot}%{_bindir}
install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/proguard
install -m 755 %{SOURCE2} %{buildroot}%{_bindir}/proguardgui
install -m 755 %{SOURCE3} %{buildroot}%{_bindir}/retrace

# jars
install -d -m 755 %{buildroot}%{_javadir}/%{name}

install -m 644 lib/proguard.jar \
           %{buildroot}%{_javadir}/%{name}/%{name}-%{version}.jar
install -m 644 lib/proguardgui.jar \
           %{buildroot}%{_javadir}/%{name}/%{name}gui-%{version}.jar
install -m 644 lib/retrace.jar \
           %{buildroot}%{_javadir}/%{name}/retrace-%{version}.jar
(cd %{buildroot}%{_javadir}/%{name} && for jar in *-%{version}*; do \
ln -s ${jar} ${jar/-%{version}/}; done)

# javadoc
install -dm 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -pr apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%clean
rm -rf %{buildroot}

%files
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/%{name}-%{version}.jar
%{_javadir}/%{name}/%{name}.jar
%{_javadir}/%{name}/retrace-%{version}.jar
%{_javadir}/%{name}/retrace.jar
%attr(0755,root,root) %{_bindir}/proguard
%attr(0755,root,root) %{_bindir}/retrace

%files gui
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/%{name}gui-%{version}.jar
%{_javadir}/%{name}/%{name}gui.jar
%attr(0755,root,root) %{_bindir}/proguardgui

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%doc docs/*

%changelog
* Wed Sep 22 2010 Ralph Apel <r.apel@r-apel.de> 4.5.1-1
- First JPP release

